@@ -2,7 +2,7 @@ from unit.utils import date_utils
 from unit.models import *
 from unit.models.check_payment import CheckPaymentCounterparty
 
-PaymentTypes = Literal["AchPayment", "BookPayment", "WirePayment", "BillPayment"]
+PaymentTypes = Literal["AchPayment", "BookPayment", "WirePayment"]
 PaymentDirections = Literal["Debit", "Credit"]
 PaymentStatus = Literal["Pending", "Rejected", "Clearing", "Sent", "Canceled", "Returned"]
 RecurringStatus = Literal["Active", "Completed", "Disabled"]
@@ -99,36 +99,21 @@ class WirePaymentDTO(BasePayment):
                               attributes["description"], attributes["amount"], attributes.get("reason"),
                               attributes.get("tags"), relationships)
 
-
-class BillPaymentDTO(BasePayment):
-    def __init__(self, _id: str, created_at: datetime, status: PaymentStatus, direction: str, description: str,
-                 amount: int, reason: Optional[str], tags: Optional[Dict[str, str]],
-                 relationships: Optional[Dict[str, Relationship]]):
-        BasePayment.__init__(self, _id, created_at, status, direction, description, amount, reason, tags, relationships)
-        self.type = 'billPayment'
-
-    @staticmethod
-    def from_json_api(_id, _type, attributes, relationships):
-        return BillPaymentDTO(_id, date_utils.to_datetime(attributes["createdAt"]), attributes["status"],
-                              attributes["direction"], attributes["description"], attributes["amount"],
-                              attributes.get("reason"), attributes.get("tags"), relationships)
-
-
-PaymentDTO = Union[AchPaymentDTO, BookPaymentDTO, WirePaymentDTO, BillPaymentDTO]
+PaymentDTO = Union[AchPaymentDTO, BookPaymentDTO, WirePaymentDTO]
 
 AchReceivedPaymentStatus = Literal["Pending", "Advanced", "Completed", "Returned"]
 
 
 class AchReceivedPaymentDTO(object):
     def __init__(self, _id: str, created_at: datetime, status: AchReceivedPaymentStatus, was_advanced: bool,
-                 completion_date: date, return_reason: Optional[str], amount: int, description: str,
+                 is_advanceable: bool, direction: str, completion_date: date, return_reason: Optional[str], amount: int, description: str,
                  addenda: Optional[str], company_name: str, counterparty_routing_number: str, trace_number: str,
                  sec_code: Optional[str], tags: Optional[Dict[str, str]],
                  relationships: Optional[Dict[str, Relationship]]):
         self.id = _id
         self.type = "achReceivedPayment"
         self.attributes = {"createdAt": created_at, "status": status, "wasAdvanced": was_advanced,
-                           "completionDate": completion_date, "returnReason": return_reason, "description": description,
+                           "isAdvanceable": is_advanceable, "direction": direction, "completionDate": completion_date, "returnReason": return_reason, "description": description,
                            "amount": amount, "addenda": addenda, "companyName": company_name,
                            "counterpartyRoutingNumber": counterparty_routing_number, "traceNumber": trace_number,
                            "secCode": sec_code, "tags": tags}
@@ -137,7 +122,7 @@ class AchReceivedPaymentDTO(object):
     @staticmethod
     def from_json_api(_id, _type, attributes, relationships):
         return AchReceivedPaymentDTO(_id, date_utils.to_datetime(attributes["createdAt"]), attributes["status"],
-                                     attributes["wasAdvanced"], date_utils.to_date(attributes["completionDate"]),
+                                     attributes["wasAdvanced"], attributes.get("isAdvanceable"), attributes["direction"], date_utils.to_date(attributes["completionDate"]),
                                      attributes.get("returnReason"), attributes["amount"], attributes["description"],
                                      attributes.get("addenda"), attributes.get("companyName"),
                                      attributes.get("counterpartyRoutingNumber"), attributes.get("traceNumber"),
